@@ -7,5 +7,5 @@ function docker-run {
         -u "$(id -u):$(id -g)" "quay.io/pypa/$1" "${@:2}"
 }
 
-docker-run manylinux_2_24_x86_64 ./build.sh
-docker-run manylinux_2_24_i686 linux32 ./build.sh
+python -m build -s
+docker-run manylinux_2_28_x86_64 ./build.sh
